@@ -53,8 +53,7 @@ class PagamentoBaseResource(restful.Resource):
     def forma_de_pagamento(self):
         if not self._forma_de_pagamento:
             try:
-                forma_pagamento = FormaDePagamento.objects.get(id=self.pagamento_id, ativo=True)
-                self._forma_de_pagamento = {"id": forma_pagamento.id, "codigo": forma_pagamento.codigo, "nome": forma_pagamento.nome}
+                self._forma_de_pagamento = FormaDePagamento.objects.get(id=self.pagamento_id, ativo=True).to_dict(com_configuracao=False)
             except FormaDePagamento.DoesNotExist:
                 self._forma_de_pagamento = {"erro": u"Não foi encontrada forma de pagamento ativa com id {}".format(self.pagamento_id), "status": 404}
         return self._forma_de_pagamento
