@@ -67,8 +67,7 @@ class FormaDePagamento(models.FormaPagamento, Plugavel):
                     pgc.conta_id
                FROM configuracao.tb_pagamento as pg
                LEFT OUTER JOIN configuracao.tb_pagamento_configuracao as pgc on (pgc.pagamento_id = pg.pagamento_id AND pgc.conta_id=%s)
-               WHERE pg.pagamento_ativado = true""",
-               [conta_id]
+               WHERE pg.pagamento_ativado = true;""", [conta_id]
         )
 
     def to_dict(self, com_configuracao=True):
